@@ -204,3 +204,5 @@
 ( cd opt/kde/share/doc/HTML/en/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/konqueror ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/konqueror ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/config/kdm ; rm -rf Xsession )
+( cd opt/kde/share/config/kdm ; ln -sf /etc/X11/xdm/Xsession Xsession )
